searchData={"items":[{"type":"module","title":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency","doc":"","ref":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency.html"},{"type":"module","title":"Basics - CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency","doc":"> #### This check is disabled by default. {: .neutral}\n>\n> [Learn how to enable it](config_file.html#checks) via `.credo.exs`.\n\n\n\nThis check has a base priority of `high` and works with any version of Elixir.","ref":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency.html#module-basics"},{"type":"module","title":"Explanation - CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency","doc":"Ensures that if one function starting with `do:` keyword definition within the module spans multiple lines\n(i.e., `do:` on a new line), all similar function definitions with the same name must also be multi-line for consistency.\n\nhttps://github.com/rrrene/credo/blob/master/CHANGELOG.md#add-ids-to-checks,\nChecks are sorted by IDs, considering naming convention, the `ID` of this custom check is `EX31001`, where:\n- `EX` - standing for elixir\n- `3` - standing for category `readability`\n- `1` - standing for `Custom Credo Checks`, considering docs: `The second digit is always 0 for Credo's standard checks`\n- `001` - standing for a unique identifier (max 999 checks per `category` as per docs)","ref":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency.html#module-explanation"},{"type":"module","title":"Usage - CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency","doc":"Add the needed custom check into to your `.credo.exs` file:\n\n  ```elixir\n%{\n  configs: [\n    %{\n      checks: %{\n        enabled: [\n          ..., # Other checks\n          {CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency, []}\n        ]\n      }\n    }\n  ]\n}\n```","ref":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency.html#module-usage"},{"type":"module","title":"Examples of different function definitions and how are they treated - CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency","doc":"```elixir\ndefmodule SampleModule do\n  #do on same line\n  def get_type(%{type: type}), do: type |> Map.get(:coding) |> hd() |> Map.get(:code)\n\n  #do on same line\n  def get_type(%{\n    type: type,\n    value: value\n  }), do: type |> Map.get(:coding) |> hd() |> Map.get(:code)\n\n  #do on next line\n  def get_type(%{\n    type: :ok,\n  }),\n    do:  %{coding: [%{code: :ok}]} |> Map.get(:coding) |> hd() |> Map.get(:code)\n\n  #do on same line\n  def get_type(%{\n    type: :ok_1,\n  }), do:\n     %{coding: [%{code: :ok_1}]} |> Map.get(:coding) |> hd() |> Map.get(:code)\n\n  #do on same line\n  def get_type(%{\n    type: :ok_2,\n  }), do: %{coding: [%{code: :ok_2}]}\n    |> Map.get(:coding)\n    |> hd()\n    |> Map.get(:code)\n\n  #do on same line\n  def get_type(%{\n    type: :ok_3,\n  }), do: :ok_3\n\n  #ignored because is a full body function\n  def get_type(%{\n    type: :ok_3,\n  }) do\n    :ok_3\n  end\n\n  # do on same line\n  defp get_type(nil, nil), do: nil\n\n  # do on same line\n  defp get_type(%{\n    item: \"item\"\n  }, nil), do: nil\n\n  # do on same line\n  defp get_type(\n    %{\n      item: \"item\",\n      item2: \"item2\"\n    },\n    %{another: \"another\"}\n  ), do: nil\n\n  # do on next line\n  defp get_type(%{type: :test}, :ok),\n    do: :ok\n\n  # do on next line\n  defp get_type(%{\n    type: :test,\n    value: :error\n  }, :ok),\n    do: :ok\n\n  # ignored because it is a full body function\n  defp get_type(%{\n    type: :test,\n    value: :error2\n  }, :ok) do\n    :ok\n  end\n\n  # ignored because it is a full body function\n  defp get_type(%{\n    type: :test,\n    value: :error3\n  }, :ok) do\n    :ok\n    |> to_string()\n    |> IO.inspect(label: \"---- ok ----\", limit: :infinity)\n  end\n\n  # do on next line\n  defp get_type(nil, :ok),\n    do: :ok\n\n  # do on next line\n  defp get_type(nil, :err),\n    do: :err\n        |> to_string()\n        |> IO.inspect(label: \"---- io ----\", limit: :infinity)\nend\n```","ref":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency.html#module-examples-of-different-function-definitions-and-how-are-they-treated"},{"type":"module","title":"Check-Specific Parameters - CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency","doc":"*There are no specific parameters for this check.*","ref":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency.html#module-check-specific-parameters"},{"type":"module","title":"General Parameters - CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency","doc":"Like with all checks, [general params](check_params.html) can be applied.\n\nParameters can be configured via the [`.credo.exs` config file](config_file.html).","ref":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency.html#module-general-parameters"},{"type":"function","title":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency.run/2","doc":"Run the check on the given source file.","ref":"CredoExt.Check.Readability.DoKeywordFunctionsLineConsistency.html#run/2"},{"type":"module","title":"CredoExt.Plugin","doc":"This is the Credo plugin that includes the custom checks.","ref":"CredoExt.Plugin.html"},{"type":"function","title":"CredoExt.Plugin.checks/0","doc":"","ref":"CredoExt.Plugin.html#checks/0"},{"type":"function","title":"CredoExt.Plugin.init/1","doc":"","ref":"CredoExt.Plugin.html#init/1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}